@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.5.0   update date: 2022-09-24
+# Version : 1.5.1   update date: 2023-03-08
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -255,6 +255,16 @@ chmod 0755 $INSTALL_DIR 2>/dev/null
 loginfo "Execute software install, this will take a moment."
 timeout 1800 ${WORKDIR}/install/ids_install -i silent -DLICENSE_ACCEPTED=TRUE -DUSER_INSTALL_DIR=${INSTALL_DIR:-/opt/${USER_NAME}}
 
+if [ ! $? -eq 0 ]; then
+  loginfo "Install Error! remove install file."
+  if [ -d ${INSTALL_DIR:-/opt/${USER_NAME}} ]; then
+    rm -rf ${INSTALL_DIR:-/opt/${USER_NAME}}
+  fi
+  userdel -r gbasedbt 2>/dev/null
+  groupdel gbasedbt 2>/dev/null
+  exit 6
+fi
+
 cd ${WORKDIR}
 if [ ! x"$CSDKPACKNAME" = x ]; then
   mkdir -p ${WORKDIR}/csdk 2>/dev/null
@@ -525,7 +535,7 @@ sed -i "s#^DUMPSHMEM.*#DUMPSHMEM 0#g" $CFGFILE
 sed -i 's#^ALARMPROGRAM.*#ALARMPROGRAM $GBASEDBTDIR/etc/log_full.sh#g' $CFGFILE
 sed -i "s#^LTAPEDEV.*#LTAPEDEV /data/backup/logs#g" $CFGFILE
 sed -i "s#^DBSERVERALIASES.*#DBSERVERALIASES ${GBASESERVER}_ssl,${GBASESERVER}_shm#g" $CFGFILE
-# sed -i "s#^IFX_FOLDVIEW.*#IFX_FOLDVIEW 0#g" $CFGFILE
+sed -i "s#^IFX_FOLDVIEW.*#IFX_FOLDVIEW 0#g" $CFGFILE
 
 if [ $NUMMEM -le 4096 ]; then
   sed -i "s#^DS_TOTAL_MEMORY.*#DS_TOTAL_MEMORY 128000#g" $CFGFILE
